//+------------------------------------------------------------------+
//|                                         FX MA 3.mq4              |
//+------------------------------------------------------------------+

#define MAGICMA  20050555

extern bool   MoneyManagement    = false;     
extern double LotsPercent        = 2;       
extern double ManualLotSize      = 0.1;      
extern double StopLoss           = 55;
extern double TakeProfit         = 800;
extern double MovingPeriod       = 21;
extern double MovingShift        = 12;
extern int    TrailingStop       = 65;

//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
  double MinLot=NormalizeDouble(MarketInfo(Symbol(),MODE_MINLOT),2);
  double MaxLot=NormalizeDouble(MarketInfo(Symbol(),MODE_MAXLOT),2);
  double LotStep=NormalizeDouble(MarketInfo(Symbol(),MODE_LOTSTEP),2);
  double FullMargin=MarketInfo(Symbol(),MODE_MARGINREQUIRED);
  double LotSize,Lot;
  int LotDigit;
  string MM="";
  
  //////////////////////////////  
  if(MoneyManagement==true)
  {
  LotSize=(AccountBalance()/100000)*LotsPercent;
  }
  ////////////////////////////////////////////////// 
  if(MoneyManagement==false) LotSize=ManualLotSize;
  /////////////////////////////////////////////
  if(LotSize<MinLot) LotSize=MinLot;
  if(LotSize>MaxLot) LotSize=MaxLot;
  /////////////////////////////////////////////
  if(LotStep==1) LotDigit=0;
  if(LotStep==0.1) LotDigit=1;
  if(LotStep==0.01) LotDigit=2;
  
  //////////////////////////////////////////
  Lot= MathFloor(LotSize/LotStep)*LotStep;
   return(Lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double ma;
   int    res;
//---- go trading only for first tiks of new bar
   static datetime Time0; if (Time0 == Time[0]) return(0); Time0 = Time[0];
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_SMA,PRICE_CLOSE,0);
//---- sell conditions
   if(Open[1]>ma && Close[1]<ma)  
     {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,Bid+StopLoss*DigitPoint(),Bid-TakeProfit*DigitPoint(),"",MAGICMA,0,Red);
      if (res<0) Alert("OpenOrder failed: ", GetLastError());
      return;
     }
//---- buy conditions
   if(Open[1]<ma && Close[1]>ma)  
     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,Ask-StopLoss*DigitPoint(),Ask+TakeProfit*DigitPoint(),"",MAGICMA,0,Blue);
      if (res<0) Alert("OpenOrder failed: ", GetLastError());
      return;
     }

  }
//+------------------------------------------------------------------+
//| Trailing Stop function                                           |
//+------------------------------------------------------------------+
void Trailing_Stop()
   {
   for(int cnt = OrdersTotal() - 1; cnt >= 0; cnt--)
      {
      OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);
      //----
      if(OrderSymbol() == Symbol() && OrderMagicNumber() == MAGICMA)
         {       
	  	   if(OrderType() == OP_BUY)
	  	      {
	  		   if(TrailingStop > 0) 
	  		      {
			      if(Bid - OrderOpenPrice() >= TrailingStop *DigitPoint())
			         {
	               if(OrderStopLoss() < (Bid - DigitPoint()*TrailingStop)) 
                     {					   
				         OrderModify(OrderTicket(), OrderOpenPrice(), Bid - DigitPoint()*TrailingStop, 0, 0, Yellow);
				         return(0);
	  		            }
	  		         }
	  		      }
	  		   }
	  	   if(OrderType() == OP_SELL) 
	  	      {
	  	      if(TrailingStop > 0) 
	  	         {
		         if(OrderOpenPrice() - Ask >= TrailingStop *DigitPoint())
		            {
		            if(OrderStopLoss() > (Ask + DigitPoint()*TrailingStop))
		               {
		               OrderModify(OrderTicket(), OrderOpenPrice(), Ask + DigitPoint()*TrailingStop, 0, 0, Purple);
		               return(0);
		               }
   	            }
               } 
            }
         }
      }
   }

//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
   double ma;
//---- go trading only for first tiks of new bar
   static datetime Time0; if (Time0 == Time[0]) return(0); Time0 = Time[0];
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_SMA,PRICE_CLOSE,0);
//----
  
   for(int i=OrdersTotal()-1; i>=0; i--) 
      
      if (OrderSelect(i, SELECT_BY_POS)                 // Only my orders w/
                 &&  OrderMagicNumber()  == MAGICMA             // my magic number
                 &&  OrderSymbol()       == Symbol() ){              // and my pair.
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
         if(Open[1]>ma && Close[1]<ma) OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(Open[1]<ma && Close[1]>ma) OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }

//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
      if(CalculateCurrentOrders(Symbol())==0) 
    {
    CheckForOpen();
    }
   else
    {
     Trailing_Stop() ;
     CheckForClose() ;
    }
    Comment("Forex Steady Growth status OK");
  }
//+------------------------------------------------------------------+---+
//+-----------------------------------------------------------------------------------------------------+
//DIGITS PART//
  double DigitPoint()
  {
  double MYpoint=Point;
  ////////////////////////////////////
  if(Digits==5||Digits==3)
  {
  MYpoint=Point*10;
  }
  return(MYpoint);
  }
//+-----------------------------------------------------------------------------------------------------+

